@@ -297,7 +297,7 @@ qgcomp.noboot <- function(f, data, expnms=NULL, q=4, breaks=NULL, id=NULL, alpha
   #' @return a qgcompfit object, which contains information about the effect
   #'  measure of interest (psi) and associated variance (var.psi), as well
   #'  as information on the model fit (fit) and information on the 
-  #'  weights/standardized coefficients in the positive (pweights) and 
+  #'  weights/standardized coefficients in the positive (pos.weights) and 
   #'  negative (nweight) directions.
   #' @concept variance mixtures
   #' @import stats arm
@@ -308,7 +308,7 @@ qgcomp.noboot <- function(f, data, expnms=NULL, q=4, breaks=NULL, id=NULL, alpha
   #' qgcomp.noboot(f=y ~ z + x1 + x2, expnms = c('x1', 'x2'), data=dat, q=2)
   if (is.null(expnms)) {
     expnms <- attr(terms(f, data = data), "term.labels")
-    cat("Including all model terms as exposures of interest\n")      
+    message("Including all model terms as exposures of interest\n")      
   }
   lin = checknames(expnms)
   if(!lin) stop("Model appears to be non-linear: use qgcomp.boot instead")
@@ -349,16 +349,16 @@ qgcomp.noboot <- function(f, data, expnms=NULL, q=4, breaks=NULL, id=NULL, alpha
     # 'weights'
     wcoef <- fit$coefficients[expnms]
     names(wcoef) <- gsub("_q", "", names(wcoef))
-    poscoef <- which(wcoef > 0)
-    negcoef <- which(wcoef <= 0)
-    pweights <- abs(wcoef[poscoef]) / sum(abs(wcoef[poscoef]))
-    nweights <- abs(wcoef[negcoef]) / sum(abs(wcoef[negcoef]))
+    pos.coef <- which(wcoef > 0)
+    neg.coef <- which(wcoef <= 0)
+    pos.weights <- abs(wcoef[pos.coef]) / sum(abs(wcoef[pos.coef]))
+    neg.weights <- abs(wcoef[neg.coef]) / sum(abs(wcoef[neg.coef]))
     # 'post-hoc' positive and negative estimators 
     # similar to constrained gWQS
-    pos.psi <- sum(wcoef[poscoef])
-    neg.psi <- sum(wcoef[negcoef])
-    #nmpos <- names(pweights)
-    #nmneg <- names(nweights)
+    pos.psi <- sum(wcoef[pos.coef])
+    neg.psi <- sum(wcoef[neg.coef])
+    #nmpos <- names(pos.weights)
+    #nmneg <- names(neg.weights)
     #se.pos.psi <- se_comb(nmpos, covmat = mod$cov.scaled)
     #se.neg.psi <- se_comb(nmneg, covmat = mod$cov.scaled)
     qx <- qdata[, expnms]
@@ -366,13 +366,14 @@ qgcomp.noboot <- function(f, data, expnms=NULL, q=4, breaks=NULL, id=NULL, alpha
     res <- list(
       qx = qx, fit = fit, 
       psi = estb[-1], var.psi = seb[-1] ^ 2, covmat.psi=c('psi1' = seb[-1]^2), ci = ci[-1,],
-      coef = estb, var.coef = seb ^ 2, covmat.coef=c('(Intercept)' = seb[2]^2, 'psi1' = seb[2]^2), ci.coef = ci,
+      coef = estb, var.coef = seb ^ 2, covmat.coef=c('(Intercept)' = seb[1]^2, 'psi1' = seb[2]^2), 
+      ci.coef = ci,
       expnms=expnms, q=q, breaks=br, degree=1,
       pos.psi = pos.psi, neg.psi = neg.psi,
-      pweights = sort(pweights, decreasing = TRUE),
-      nweights = sort(nweights, decreasing = TRUE), 
-      psize = sum(abs(wcoef[poscoef])),
-      nsize = sum(abs(wcoef[negcoef])),
+      pos.weights = sort(pos.weights, decreasing = TRUE),
+      neg.weights = sort(neg.weights, decreasing = TRUE), 
+      pos.size = sum(abs(wcoef[pos.coef])),
+      neg.size = sum(abs(wcoef[neg.coef])),
       bootstrap=FALSE,
       cov.yhat=NULL
     )
@@ -453,12 +454,13 @@ qgcomp.boot <- function(f, data, expnms=NULL, q=4, breaks=NULL, id=NULL, alpha=0
   #' qgcomp.noboot(y ~ z + x1 + x2, expnms = c('x1', 'x2'), data=dat, q=4, family=gaussian())
   #' # Marginal linear slope (population average slope, for a purely linear, 
   #' #  additive model this will equal the conditional)
+  #'  \donttest{
   #' qgcomp.boot(f=y ~ z + x1 + x2, expnms = c('x1', 'x2'), data=dat, q=4, 
-  #'   family=gaussian(), B=10) #increase B to at least 200 in actual examples
+  #'   family=gaussian(), B=200) # B should be at least 200 in actual examples
   #'   
   #' # Population average mixture slope which accounts for non-linearity and interactions
   #' qgcomp.boot(y ~ z + x1 + x2 + I(x1^2) + I(x2*x1), family="gaussian", 
-  #'  expnms = c('x1', 'x2'), data=dat, q=4, B=6)
+  #'  expnms = c('x1', 'x2'), data=dat, q=4, B=200)
   #'  
   #' # binary outcome
   #' dat <- data.frame(y=rbinom(50,1,0.5), x1=runif(50), x2=runif(50), z=runif(50))
@@ -470,23 +472,23 @@ qgcomp.boot <- function(f, data, expnms=NULL, q=4, breaks=NULL, id=NULL, alpha=0
   #' #Marginal mixture OR (population average OR - in general, this will not equal the 
   #' # conditional mixture OR due to non-collapsibility of the OR)
   #' qgcomp.boot(y ~ z + x1 + x2, family="binomial", expnms = c('x1', 'x2'), 
-  #'   data=dat, q=2, B=6)
+  #'   data=dat, q=2, B=3)
   #'   
   #' # Population average mixture RR
   #' qgcomp.boot(y ~ z + x1 + x2, family="binomial", expnms = c('x1', 'x2'), 
-  #'   data=dat, q=2, rr=TRUE, B=6)
+  #'   data=dat, q=2, rr=TRUE, B=3)
   #'   
   #' # Population average mixture RR, indicator variable representation of x2
   #' # note that I(x==...) operates on the quantile-based category of x,
   #' # rather than the raw value
   #' res = qgcomp.boot(y ~ z + x1 + I(x2==1) + I(x2==2) + I(x2==3), 
-  #'   family="binomial", expnms = c('x1', 'x2'), data=dat, q=4, rr=TRUE, B=6)
+  #'   family="binomial", expnms = c('x1', 'x2'), data=dat, q=4, rr=TRUE, B=200)
   #' res$fit  
   #' plot(res)
   #' 
   #' # now add in a non-linear MSM
   #' res2 = qgcomp.boot(y ~ z + x1 + I(x2==1) + I(x2==2) + I(x2==3), 
-  #'   family="binomial", expnms = c('x1', 'x2'), data=dat, q=4, rr=TRUE, B=6, 
+  #'   family="binomial", expnms = c('x1', 'x2'), data=dat, q=4, rr=TRUE, B=200, 
   #'   degree=2)
   #' res2$fit  
   #' res2$msmfit  
@@ -497,19 +499,20 @@ qgcomp.boot <- function(f, data, expnms=NULL, q=4, breaks=NULL, id=NULL, alpha=0
   #' # note that I(x>...) now operates on the untransformed value of x,
   #' # rather than the quantized value
   #' res2 = qgcomp.boot(y ~ z + x1iqr + I(x2iqr>0.1) + I(x2>0.4) + I(x2>0.9), 
-  #'   family="binomial", expnms = c('x1iqr', 'x2iqr'), data=dat, q=NULL, rr=TRUE, B=6, 
+  #'   family="binomial", expnms = c('x1iqr', 'x2iqr'), data=dat, q=NULL, rr=TRUE, B=200, 
   #'   degree=2)
   #' res2
   #' # using parallel processing
-  #' res2p = qgcomp.boot(y ~ z + x1iqr + I(x2iqr>0.1) + I(x2>0.4) + I(x2>0.9), 
-  #'   family="binomial", expnms = c('x1iqr', 'x2iqr'), data=dat, q=NULL, rr=TRUE, B=6, 
+  #'
+  #' qgcomp.boot(y ~ z + x1iqr + I(x2iqr>0.1) + I(x2>0.4) + I(x2>0.9), 
+  #'   family="binomial", expnms = c('x1iqr', 'x2iqr'), data=dat, q=NULL, rr=TRUE, B=200, 
   #'   degree=2, parallel=TRUE)
-  #' res2p
+  #' }
   # character names of exposure mixture components
     if(is.null(seed)) seed = round(runif(1, min=0, max=1e8))
     if (is.null(expnms)) {
       expnms <- attr(terms(f, data = data), "term.labels")
-      cat("Including all model terms as exposures of interest\n")      
+      message("Including all model terms as exposures of interest\n")      
     }
     lin = checknames(expnms)
     if(!lin) stop("Model appears to be non-linear and I'm having trouble parsing it: 
@@ -536,7 +539,7 @@ qgcomp.boot <- function(f, data, expnms=NULL, q=4, breaks=NULL, id=NULL, alpha=0
       # then draw distribution values from quantiles of all the exposures
       # pooled together
       # TODO: allow user specification of this
-      cat("\nNote: using quantiles of all exposures combined in order to set 
+      message("\nNote: using quantiles of all exposures combined in order to set 
           proposed intervention values for overall effect (25th, 50th, 75th %ile)\n")
       intvals = as.numeric(quantile(unlist(data[,expnms]), c(.25, .5, .75)))
       br <- NULL
@@ -557,7 +560,7 @@ qgcomp.boot <- function(f, data, expnms=NULL, q=4, breaks=NULL, id=NULL, alpha=0
     psi.only <- function(i=1, f=f, qdata=qdata, intvals=intvals, expnms=expnms, rr=rr, degree=degree, nids=nids, id=id, ...){
       if(i==2){
         timeiter = as.numeric(Sys.time() - starttime)
-        if((timeiter*B/60)>0.5) cat(paste0("Expected time to finish: ", round(B*timeiter/60, 2), " minutes \n"))
+        if((timeiter*B/60)>0.5) message(paste0("Expected time to finish: ", round(B*timeiter/60, 2), " minutes \n"))
       }
       bootids <- data.frame(temp=sort(sample(unique(qdata[,id, drop=TRUE]), nids, replace = TRUE)))
       names(bootids) <- id
@@ -610,7 +613,7 @@ qgcomp.boot <- function(f, data, expnms=NULL, q=4, breaks=NULL, id=NULL, alpha=0
       coef = estb, var.coef = seb ^ 2, covmat.coef=covmat, ci.coef = ci,
       expnms=expnms, q=q, breaks=br, degree=degree,
       pos.psi = NULL, neg.psi = NULL, 
-      pweights = NULL,nweights = NULL, psize = NULL,nsize = NULL, bootstrap=TRUE,
+      pos.weights = NULL, neg.weights = NULL, pos.size = NULL,neg.size = NULL, bootstrap=TRUE,
       y.expected=msmfit$Ya, y.expectedmsm=msmfit$Yamsm, index=msmfit$A,
       bootsamps = bootsamps,
       cov.yhat=cov.yhat
@@ -708,7 +711,7 @@ qgcomp <- function(f,data=data,family=gaussian(),rr=TRUE,...){
     family <- family()
   if (is.null(family$family)) {
     if(issurv){
-      cat("Survival model\n")
+      message("Survival model\n")
     }else{
       print(family)
       stop("'family' not recognized")
@@ -764,17 +767,21 @@ print.qgcompfit <- function(x, ...){
   #' print(obj1)
   #' print(obj2)
   fam <- x$fit$family$family
-  if(!is.null(x$psize)) {
-    cat(paste0("Scaled effect size (positive direction, sum of positive coefficients = ", signif(x$psize, 3) , ")\n"))
-    if (length(x$pweights) > 0) {
-      print(x$pweights, digits = 3)
+  if(is.null(fam)){
+    printZI(x)
+    return(invisible(x))
+  }
+  if(!is.null(x$pos.size)) {
+    cat(paste0("Scaled effect size (positive direction, sum of positive coefficients = ", signif(x$pos.size, 3) , ")\n"))
+    if (length(x$pos.weights) > 0) {
+      print(x$pos.weights, digits = 3)
     } else cat("None\n")
     cat("\n")
   }
-  if(!is.null(x$nsize)) {
-    cat(paste0("Scaled effect size (negative direction, sum of negative coefficients = ", signif(-x$nsize, 3) , ")\n"))
-    if (length(x$nweights) > 0) {
-      print(x$nweights, digits = 3)
+  if(!is.null(x$neg.size)) {
+    cat(paste0("Scaled effect size (negative direction, sum of negative coefficients = ", signif(-x$neg.size, 3) , ")\n"))
+    if (length(x$neg.weights) > 0) {
+      print(x$neg.weights, digits = 3)
     } else cat("None\n")
     cat("\n")
   }
@@ -795,7 +802,7 @@ print.qgcompfit <- function(x, ...){
     testtype = "Z"
     rnm = c(paste0('psi',1:max(1, length(coef(x)))))
   }
-  if(is.null(dim(x$ci))){
+  if(is.null(dim(x$ci.coef))){
     pdat <- cbind(Estimate=coef(x), "Std. Error"=sqrt(x$var.coef), "Lower CI"=x$ci.coef[1], "Upper CI"=x$ci.coef[2], "test"=x$zstat, "Pr(>|z|)"=x$pval)
     colnames(pdat)[5] = eval(paste(testtype, "value"))
     rownames(pdat) <- rnm
@@ -836,9 +843,11 @@ plot.qgcompfit <- function(x,
   #' of the joint exposures (e.g. '1' represents 'at the first quantile for
   #' every exposure')
   #' 
-  #' @param x "qgcompfit" object from `qgcomp.noboot` or  `qgcomp.boot` functions
+  #' @param x "qgcompfit" object from `qgcomp.noboot`,  `qgcomp.boot`, 
+  #'   `qgcomp.cox.noboot`,  `qgcomp.cox.boot`, `qgcomp.zi.noboot` or `qgcomp.zi.boot` functions
   #' @param suppressprint If TRUE, suppresses the plot, rather than printing it 
-  #'   by default (it can be saved as a ggplot2 object and used programmatically)
+  #'   by default (it can be saved as a ggplot2 object (or list of ggplot2 objects if x is from a zero-
+  #'   inflated model) and used programmatically)
   #'   (default = FALSE)
   #' @param pointwisebars (boot.gcomp only) If TRUE, adds 95\%  error bars for pointwise comparisons
   #' of E(Y|joint exposure) to the smooth regression line plot
@@ -915,39 +924,83 @@ plot.qgcompfit <- function(x,
     plot.margin = unit(c(t=1, r=0.5, b=.75, l=0.0), "cm"),
     panel.border = element_blank()))
 
-  nms = unique(names(sort(c(x$pweights, x$nweights), decreasing = FALSE)))
+  if(!is.null(x$fit$family)) nms = unique(names(sort(c(x$pos.weights, x$neg.weights), decreasing = FALSE)))
   
   #vpl <- grid::viewport(width=0.525, height=1, x=0, y=0, just=c("left", "bottom"))
   #vpr <- grid::viewport(width=0.475, height=1, x=0.525, y=0, just=c("left", "bottom"))
   if(!x$bootstrap){
-    poscolwt = 1-x$pos.psi/(x$pos.psi - x$neg.psi)
-    if(length(x$pweights)==0) x$pweights = x$nweights*0
-    if(length(x$nweights)==0) x$nweights = x$pweights*0
-    pright <- ggplot() + 
-    stat_identity(aes(x=v, y=w), position = "identity", geom="bar", 
-                  data=data.frame(w=x$pweights, v=names(x$pweights)),
-                  fill=gray(poscolwt)) + 
-    scale_y_continuous(name="Positive weights", expand=c(0.000,0.000), breaks=c(0.25, 0.5, 0.75)) +
-    scale_x_discrete(limits=nms, breaks=nms, labels=nms, drop=FALSE, position="top") +
-    geom_hline(aes(yintercept=0)) + 
-    coord_flip(ylim=c(0,1)) + 
-    theme_butterfly_r
-    pleft <- ggplot() + 
-    stat_identity(aes(x=v, y=w), position = "identity", geom="bar", 
-                  data=data.frame(w=x$nweights, v=names(x$nweights)),
-                  fill=gray(1-poscolwt)) + 
-    scale_y_reverse(name="Negative weights", expand=c(0.000,0.000), breaks=c(0.25, 0.5, 0.75)) +
-    scale_x_discrete(name="Variable", limits=nms, breaks=nms, labels=nms, drop=FALSE) +
-    geom_hline(aes(yintercept=0)) + 
-    coord_flip(ylim=c(0,1)) + 
-    theme_butterfly_l
-    if((length(x$nweights)>0 & length(x$pweights)>0)){
-      maxstr = max(mapply(nchar, c(names(x$nweights), names(x$pweights))))
-      lw = 1+maxstr/20
-      p1 <- gridExtra::arrangeGrob(grobs=list(pleft, pright), ncol=2, padding=0.0, widths=c(lw,1))
+    if(!is.null(x$fit$family)){
+      # glm
+      poscolwt = 1-x$pos.psi/(x$pos.psi - x$neg.psi)
+      if(length(x$pos.weights)==0) x$pos.weights = x$neg.weights*0
+      if(length(x$neg.weights)==0) x$neg.weights = x$pos.weights*0
+      pright <- ggplot() + 
+        stat_identity(aes(x=v, y=w), position = "identity", geom="bar", 
+                      data=data.frame(w=x$pos.weights, v=names(x$pos.weights)),
+                      fill=gray(poscolwt)) + 
+        scale_y_continuous(name="Positive weights", expand=c(0.000,0.000), breaks=c(0.25, 0.5, 0.75)) +
+        scale_x_discrete(limits=nms, breaks=nms, labels=nms, drop=FALSE, position="top") +
+        geom_hline(aes(yintercept=0)) + 
+        coord_flip(ylim=c(0,1)) + 
+        theme_butterfly_r
+      pleft <- ggplot() + 
+        stat_identity(aes(x=v, y=w), position = "identity", geom="bar", 
+                      data=data.frame(w=x$neg.weights, v=names(x$neg.weights)),
+                      fill=gray(1-poscolwt)) + 
+        scale_y_reverse(name="Negative weights", expand=c(0.000,0.000), breaks=c(0.25, 0.5, 0.75)) +
+        scale_x_discrete(name="Variable", limits=nms, breaks=nms, labels=nms, drop=FALSE) +
+        geom_hline(aes(yintercept=0)) + 
+        coord_flip(ylim=c(0,1)) + 
+        theme_butterfly_l
+      if((length(x$neg.weights)>0 & length(x$pos.weights)>0)){
+        maxstr = max(mapply(nchar, c(names(x$neg.weights), names(x$pos.weights))))
+        lw = 1+maxstr/20
+        p1 <- gridExtra::arrangeGrob(grobs=list(pleft, pright), ncol=2, padding=0.0, widths=c(lw,1))
+        if(!suppressprint) {
+          grid::grid.newpage()
+          grid::grid.draw(p1)
+        }
+        if(suppressprint) return(p1)
+      }
+    }
+    if(is.null(x$fit$family)){
+      # zero inflated
+      p1 = list()
+      for(modtype in names(x$psi)){
+        nms = unique(names(sort(c(x$pos.weights[[modtype]], x$neg.weights[[modtype]]), decreasing = FALSE)))
+        poscolwt = 1-x$pos.psi[[modtype]]/(x$pos.psi[[modtype]] - x$neg.psi[[modtype]])
+        if(length(x$pos.weights[[modtype]])==0) x$pos.weights[[modtype]] = x$neg.weights[[modtype]]*0
+        if(length(x$neg.weights[[modtype]])==0) x$neg.weights[[modtype]] = x$pos.weights[[modtype]]*0
+        pright <- ggplot() + 
+          stat_identity(aes(x=v, y=w), position = "identity", geom="bar", 
+                        data=data.frame(w=x$pos.weights[[modtype]], v=names(x$pos.weights[[modtype]])),
+                        fill=gray(poscolwt)) + 
+          scale_y_continuous(name="Positive weights", expand=c(0.000,0.000), breaks=c(0.25, 0.5, 0.75)) +
+          scale_x_discrete(limits=nms, breaks=nms, labels=nms, drop=FALSE, position="top") +
+          geom_hline(aes(yintercept=0)) + 
+          coord_flip(ylim=c(0,1)) + 
+          theme_butterfly_r
+        pleft <- ggplot() + 
+          stat_identity(aes(x=v, y=w), position = "identity", geom="bar", 
+                        data=data.frame(w=x$neg.weights[[modtype]], v=names(x$neg.weights[[modtype]])),
+                        fill=gray(1-poscolwt)) + 
+          scale_y_reverse(name="Negative weights", expand=c(0.000,0.000), breaks=c(0.25, 0.5, 0.75)) +
+          scale_x_discrete(name=paste0("Variable (", modtype, " model)"), limits=nms, breaks=nms, labels=nms, drop=FALSE) +
+          geom_hline(aes(yintercept=0)) + 
+          coord_flip(ylim=c(0,1)) + 
+          theme_butterfly_l
+        if((length(x$neg.weights[[modtype]])>0 & length(x$pos.weights[[modtype]])>0)){
+          maxstr = max(mapply(nchar, c(names(x$neg.weights[[modtype]]), names(x$pos.weights[[modtype]]))))
+          lw = 1+maxstr/20
+          p1[[modtype]] <- gridExtra::arrangeGrob(grobs=list(pleft, pright), ncol=2, padding=0.0, widths=c(lw,1))
+        }
+      }
       if(!suppressprint) {
-        grid::grid.newpage()
-        grid::grid.draw(p1)
+        plfun <- function(plt){ 
+          grid::grid.newpage()
+          grid::grid.draw(plt)
+        }
+        lapply(p1, plfun)
       }
       if(suppressprint) return(p1)
     }
